@@ -231,6 +231,9 @@ class ActionConfigFile(Action, FilesCompleterMethod):
             cfg.update(cfg_file)
 
 
+print_config_skip: ContextVar = ContextVar('print_config_skip', default=False)
+
+
 class _ActionPrintConfig(Action):
     def __init__(self,
                  option_strings,
@@ -258,9 +261,18 @@ class _ActionPrintConfig(Action):
             parser = parser.parent_parser
         parser.print_config = kwargs
 
+    @staticmethod
+    @contextmanager
+    def skip_print_config():
+        t = print_config_skip.set(True)
+        try:
+            yield
+        finally:
+            print_config_skip.reset(t)
+
     @staticmethod
     def print_config_if_requested(parser, cfg):
-        if hasattr(parser, 'print_config') and not hasattr(parser, 'print_config_skip'):
+        if hasattr(parser, 'print_config') and not print_config_skip.get():
             key = parser.print_config.pop('key')
             subparser = parser.print_config.pop('subparser')
             if key is not None:
