@@ -279,7 +279,8 @@ class ArgumentParser(_ActionsContainer, argparse.ArgumentParser):
             cfg = self.merge_config(cfg, cfg_base)
 
         if env:
-            cfg_env = self.parse_env(defaults=defaults, _skip_check=True, _skip_subcommands=True)
+            with _ActionPrintConfig.skip_print_config():
+                cfg_env = self.parse_env(defaults=defaults, _skip_check=True, _skip_subcommands=True)
             cfg = self.merge_config(cfg, cfg_env)
 
         elif defaults:
@@ -585,12 +586,8 @@ class ArgumentParser(_ActionsContainer, argparse.ArgumentParser):
         Raises:
             TypeError: If there is an invalid value according to the parser.
         """
-        if self.parser_mode == 'jsonnet':
-            ext_vars, ext_codes = ActionJsonnet.split_ext_vars(ext_vars)
-            _jsonnet = import_jsonnet('_load_config_parser_mode')
-            cfg_str = _jsonnet.evaluate_snippet(cfg_path, cfg_str, ext_vars=ext_vars, ext_codes=ext_codes)
         try:
-            cfg_dict = load_value(cfg_str)
+            cfg_dict = load_value(cfg_str, path=cfg_path, ext_vars=ext_vars)
         except get_loader_exceptions() as ex:
             raise TypeError(f'Problems parsing config :: {ex}') from ex
 
@@ -907,16 +904,15 @@ class ArgumentParser(_ActionsContainer, argparse.ArgumentParser):
                 if key is not None:
                     cfg_file = cfg_file.get(key)
                 try:
-                    self.print_config_skip = True
-                    cfg_file = self._parse_common(
-                        cfg=cfg_file,
-                        env=None,
-                        defaults=False,
-                        with_meta=None,
-                        skip_check=skip_check,
-                        skip_required=True,
-                    )
-                    delattr(self, 'print_config_skip')
+                    with _ActionPrintConfig.skip_print_config():
+                        cfg_file = self._parse_common(
+                            cfg=cfg_file,
+                            env=None,
+                            defaults=False,
+                            with_meta=None,
+                            skip_check=skip_check,
+                            skip_required=True,
+                        )
                 except (TypeError, KeyError, ParserError) as ex:
                     raise ParserError(f'Problem in default config file "{default_config_file}" :: {ex.args[0]}') from ex
             cfg = self.merge_config(cfg_file, cfg)
@@ -940,8 +936,7 @@ class ArgumentParser(_ActionsContainer, argparse.ArgumentParser):
         """Logs error message if a logger is set, calls the error handler and raises a ParserError."""
         self._logger.error(message)
         if self._error_handler is not None:
-            with _suppress_stderr():
-                self._error_handler(self, message)
+            self._error_handler(self, message)
         if ex is None:
             raise ParserError(message)
         else:
