@@ -10,7 +10,7 @@ import unittest
 import warnings
 import yaml
 from io import StringIO
-from contextlib import redirect_stdout
+from contextlib import redirect_stderr, redirect_stdout
 from collections import OrderedDict
 from random import randint, shuffle
 from jsonargparse import (
@@ -523,6 +523,21 @@ class AdvancedFeaturesTests(unittest.TestCase):
         self.assertEqual(cfg, Namespace(subcommand=None))
 
 
+    def test_subcommand_print_config_default_env_issue_126(self):
+        subparser = ArgumentParser()
+        subparser.add_argument('--config', action=ActionConfigFile)
+        subparser.add_argument('--o', type=int, default=1)
+
+        parser = ArgumentParser(error_handler=None, default_env=True)
+        subcommands = parser.add_subcommands()
+        subcommands.add_subcommand('a', subparser)
+
+        out = StringIO()
+        with redirect_stdout(out), self.assertRaises(SystemExit):
+            parser.parse_args(['a', '--print_config'])
+        self.assertEqual(yaml.safe_load(out.getvalue()), {'o': 1})
+
+
     @unittest.skipIf(not url_support or not responses, 'validators, requests and responses packages are required')
     @responses_activate
     def test_urls(self):
@@ -1021,11 +1036,13 @@ class OtherTests(unittest.TestCase):
 
 
     def test_usage_and_exit_error_handler(self):
-        with _suppress_stderr():
+        err = StringIO()
+        with redirect_stderr(err):
             parser = ArgumentParser()
             parser.add_argument('--val', type=int)
             self.assertEqual(8, parser.parse_args(['--val', '8']).val)
             self.assertRaises(SystemExit, lambda: parser.parse_args(['--val', 'eight']))
+        self.assertIn('Parser key "val":', err.getvalue())
 
 
     def test_error_handler_property(self):
